%great_run_2013_stats
%
% Function which performs a statistical analysis on timings data from the
% Great Runs (North and South) in 2013.
% http://www.greatrun.org
%
% Great South Run. (Portsmouth). 27th October 2013. 10 miles.
% http://www.bbc.co.uk/sport/0/athletics/24694540
%
% Andrew French 10857	Achilles Club	Position 1159  01:15:18
% James Webster	1285	Winchester & District Athletic Club	 Position 153  01:04:32
%
% Great North Run. (South Shields). 15th September 2013. 13.1 miles. (Half Marathon).
% http://www.bbc.co.uk/news/uk-england-tyne-24081957
%
% Absolute Time bins for histograms are set to be every 30s, from 40mins to 'more
% than four hours'.
%
% For North, South comparison, the great North times are divided by 13.1/10
% i.e assuming the pace for most athletes is the same for both races.
% Obviously this is somewhat flawed, but it is perhaps the first step to
% compare the two races fairly.

function great_run_2013_stats

%% Set bins of histogram and any other inputs %%

%Set sensible plot limits for time bins
t_min = 40;
t_max = 5*60;

%Time bin width /minutes
dt = 0.5;

%Set time limits for plots
plot_t_min = t_min;
plot_t_max = 4*60;

%Plot colours
M_colour = [185,205,229]/255;
F_colour = [230,185,184]/255;
all_colour = [195,214,155]/255;

%Wheelchair athlete numbers (excluded from analysis
%as the elite athletes are considerably faster!)
great_north_wheelchairs = [
    181,...
    281,...
    182,...
    282,...
    185,...
    283,...
    284,...
    189,...
    184,...
    191,...
    188,...
    183,...
    192,...
    193,...
    199,...
    198,...
    197,...
    196,...
    194,...
    190 ];
great_south_wheelchairs = 14519;

%

%% Load and process raw data from .csv files %%

%Display message to command window
clc;
disp(' ')
disp(' Great Run 2013 Analysis. A. French Nov 2013')
disp(' Loading Great Run 2013 data .....')
t0 = tic;

%Load Great South Run data. Fields are:
% great_south.racenumber
% great_south.gender
% great_south.timefinish
% great_south.categoryposition
great_south = csv2struct('gsr2013.csv');

%Load Great North run data
great_north = csv2struct('gnr2013.csv');

%Remove wheelchair athletes
i = [];
for n=1:length(great_north.racenumber)
    j = find( great_north_wheelchairs == great_north.racenumber(n) );
    if ~isempty(j)
        i = [i,n];
    end
end
great_north.racenumber(i) = [];  
great_north.gender(i) = [];  
great_north.timefinish(i) = [];  
great_north.categoryposition(i) = [];  
i = [];
for n=1:length(great_south.racenumber)
    j = find( great_south_wheelchairs == great_south.racenumber(n) );
    if ~isempty(j)
        i = [i,n];
    end
end
great_south.racenumber(i) = [];  
great_south.gender(i) = [];  
great_south.timefinish(i) = [];  
great_south.categoryposition(i) = [];  

%Change timefinish from fractions of a 24 day in hours to minutes
great_south.timefinish = great_south.timefinish * 24 * 60;
great_north.timefinish = great_north.timefinish * 24 * 60;

%Split into male, female and all time datasets. Sort each by time in ascending
%order
great_south_F = sort( great_south.timefinish(  strcmp( great_south.gender, 'F' )  ));
great_south_M = sort( great_south.timefinish(  strcmp( great_south.gender, 'M' )  ));
great_south_all = sort( great_south.timefinish );
great_north_F = sort( great_north.timefinish(  strcmp( great_north.gender, 'F' )  ));
great_north_M = sort( great_north.timefinish(  strcmp( great_north.gender, 'M' )  ));
great_north_all = sort( great_north.timefinish );

%Clear not needed data
clear great_south great_north

%Scale Great North data i.e. determine 10 mile prediction
great_north_F_scaled = north2south( great_north_F );
great_north_M_scaled = north2south( great_north_M );
great_north_all_scaled = north2south( great_north_all );

%

%% Construct histograms, perform statistics and determine probability density functions %%
disp(' Computing statistics .....')
south_M = statistica( great_south_M , t_min, t_max, dt );
south_F = statistica( great_south_F , t_min, t_max, dt );
south_all = statistica( great_south_all , t_min, t_max, dt );
north_M = statistica( great_north_M , t_min, t_max, dt );
north_F = statistica( great_north_F , t_min, t_max, dt );
north_all = statistica( great_north_all , t_min, t_max, dt );
north_M_scaled = statistica( great_north_M_scaled , t_min, t_max, dt );
north_F_scaled = statistica( great_north_F_scaled , t_min, t_max, dt );
north_all_scaled = statistica( great_north_all_scaled , t_min, t_max, dt );

%Determine proportion of people between one and two hours
south_M_60_120 = time_proportion( 60, 120 , south_M.pdf, south_M.x_bin_edges )
south_F_60_120 = time_proportion( 60, 120 , south_F.pdf, south_F.x_bin_edges )
south_all_60_120 = time_proportion( 60, 120 , south_all.pdf, south_all.x_bin_edges )
north_M_60_120_10mile = time_proportion( 60, 120 , north_M_scaled.pdf, north_M_scaled.x_bin_edges )
north_F_60_120_10mile = time_proportion( 60, 120 , north_F_scaled.pdf, north_F_scaled.x_bin_edges )
north_all_60_120_10mile = time_proportion( 60, 120 , north_all_scaled.pdf, north_all_scaled.x_bin_edges )
north_M_60_120 = time_proportion( 60, 120 , north_M.pdf, north_M.x_bin_edges )
north_F_60_120 = time_proportion( 60, 120 , north_F.pdf, north_F.x_bin_edges )
north_all_60_120 = time_proportion( 60, 120 , north_all.pdf, north_all.x_bin_edges )

%Determine maximum PDF for common graph scaling
max_PDF = max( [ 
    max(south_F.pdf),...
    max(south_M.pdf),...
    max(south_all.pdf),...
    max(north_F.pdf),...
    max(north_M.pdf),...
    max(north_all.pdf),...
    max(north_F_scaled.pdf),...
    max(north_M_scaled.pdf),...
    max(north_all_scaled.pdf) ] );

%

%% Plot histograms and save as PNG files %%
disp(' Plotting histograms ......')
fig = figure('name','Great Run statistics 2013','color', [1 1 1]);
pdf_plot(south_M, [plot_t_min, plot_t_max], [0,max_PDF], 'time /minutes', 'Great South Run 2013 (Men)', 'Great South 2013 Men', M_colour,  fig ); clf;
pdf_plot(south_F, [plot_t_min, plot_t_max], [0,max_PDF],  'time /minutes', 'Great South Run 2013 (Women)', 'Great South 2013 Women', F_colour,  fig ); clf;
pdf_plot(south_all, [plot_t_min, plot_t_max], [0,max_PDF],  'time /minutes', 'Great South Run 2013 (All)',  'Great South 2013 All', all_colour,  fig ); clf;
pdf_plot(north_M, [plot_t_min, plot_t_max], [0,max_PDF],  'time /minutes', 'Great North Run 2013 (Men)',  'Great North 2013 Men', M_colour,  fig ); clf;
pdf_plot(north_F, [plot_t_min, plot_t_max], [0,max_PDF],  'time /minutes', 'Great North Run 2013 (Women)',  'Great North 2013 Women', F_colour,  fig ); clf;
pdf_plot(north_all, [plot_t_min, plot_t_max], [0,max_PDF],  'time /minutes', 'Great North Run 2013 (All)',  'Great North 2013 All', all_colour,  fig ); clf;
pdf_plot(north_M_scaled, [plot_t_min, plot_t_max], [0,max_PDF],  'time /minutes', 'Great North Run 2013 (Men) 10 mile prediction',  'Great North 2013 Men 10 mile', M_colour,  fig ); clf;
pdf_plot(north_F_scaled, [plot_t_min, plot_t_max], [0,max_PDF],  'time /minutes', 'Great North Run 2013 (Women) 10 mile prediction', 'Great North 2013 Women 10 mile', F_colour,  fig ); clf;
pdf_plot(north_all_scaled, [plot_t_min, plot_t_max], [0,max_PDF],  'time /minutes', 'Great North Run 2013 (All) 10 mile prediction', 'Great North 2013 All 10 mile', all_colour,  fig )
close(gcf);
disp(' ')
disp([' Analysis complete in ', num2str( toc(t0) ),' seconds.' ] );

%%

%13.1 mile to 10 mile time predictor
function south_t = north2south( north_t )
south_t = north_t/( 13.1/10 );

%%

%Determines proportion of runners between times t1 and t2
function p = time_proportion( t1, t2 , PDF, x_bin_edges )
[Y_pp,p2] = calculus( x_bin_edges, PDF, t2,...
    'integ','spline',0);
[Y_pp,p1] = calculus( x_bin_edges, PDF, t1,...
    'integ','spline',0);
p = p2-p1;

%End of code