%statistica
% Function which takes a vector of data x and performs a statistical
% analysis.
%
% Requires MATLAB statistics toolbox and calculus.m function.
%
% LAST UPDATED by Andy French 23rd November 2013.
%
% Syntax: s = statistica( x, xmin, xmax, dx )
%
% x               Data vector
% xmin            Minimum edge of data value bins
% xmax            Max edge of data value bins
% dx              Bin width
%
% s.x_sort        x in ascending order
% s.N             Number of data points
% s.mean          Mean x
% s.median        Median of x
% s.std           Standard deviation of x
% s.skew          Skewness of x
% s.kurtosis      Kurtosis of x
% s.x_bin_edges   Edges of histogram bins 
% s.hist          Counts of x values between bin edges
% s.hist_area     Area under histogram (actually a bar chart, as area isn't
%                 total frequency s.N)
% s.pdf           Probability density function. Area under curve is unity.
% s.norm_fit      Fit of a normal distribution, to be plotted against
%                 s.x_sort
% s.cumfreq       Normalized cumulative frequency %, to be plotted against
%                 x_bin edges
% s.LQ            x corresponding to 25% of cumulative frequency
% s.UQ            x corresponding to 75% of cumulative frequency
% s.M             Meadian computed from cumulative frequency curve (50%)
% s.IQR           Inter-quartile range UQ-LQ
% s.min_x         Minimum value of x
% s.max_x         Maximum value of x
% s.range_x       Range of values of x

function s = statistica( x, xmin, xmax, dx )

%Sort x in ascending order
s.x_sort = sort(x);

%Determine basic statistics
s.N = length(x);
s.min_x = min(x);
s.max_x = max(x);
s.range_x = s.max_x - s.min_x;
s.mean = mean(x);
s.median = median(x);
s.std = std(x);
s.skew = skewness(x);
s.kurtosis = kurtosis(x);

%Create histogram bins
s.x_bin_edges = xmin : dx : xmax;

%Create histogram and PDF
s.hist = histc( x, s.x_bin_edges );
[Y_pp,s.hist_area] = calculus( s.x_bin_edges, s.hist, s.x_bin_edges(end),...
    'integ','spline',0);
s.pdf = s.hist/s.hist_area;

%Create normal distribution PDF fitted to the data
s.norm_fit = (1/sqrt(2*pi*s.std^2)) *...
    exp( -( (s.x_sort - s.mean).^2 )/(2*s.std^2) );

%Determine cumulative frequency %
s.cumfreq = 100*cumsum(s.pdf);

%Determine LQ, UQ, IQR
[ s.cumfreq, s.LQ, s.UQ, s.M, s.IQR ] = cumfreq( s.x_sort );

%%

%Cumulative frequency 
function [ c, LQ, UQ, M, IQR ] = cumfreq( x )
c = 100*ones(size(x));
for n=1:length(x)
    c(n) = 100*length( find( x<=x(n) ) )/length(x);
end
i = find( abs((c-25) ) == min( abs(c-25) ) );
LQ = x( i(1) ); 
i = find( abs((c-75) ) == min( abs(c-75) ) );
UQ = x( i(1) ); 
IQR = UQ - LQ;
i = find( abs((c-50) ) == min( abs(c-50) ) );
M = x( i(1) ); 

%End of code